import { compile as platformCompile } from '@lwc/sfdc-lwc-compiler';
import { Workspace } from '../../types/index.js';
import { measureOperationTime } from '../util/telemetry.js';
function transformOptionsToPlatformCompileConfig(ctx, transformOptions, files) {
    const { enableDynamicComponents, enableLightningWebSecurityTransforms, experimentalComplexExpressions, apiVersion, name, namespace, experimentalDynamicComponent, outputConfig, } = transformOptions;
    const options = {
        // variable options
        allowDynamicComponents: enableDynamicComponents,
        enableLightningWebSecurityTransforms: enableLightningWebSecurityTransforms,
        enableTemplateExpressions: experimentalComplexExpressions,
        apiVersion: apiVersion,
        // Standard options
        disableProcessNodeEnv: true,
        dynamicImport: 'allowed',
        forceNamedExports: true,
        strictCSSTokenCollection: true,
        // Enable HMR always in dev server
        enableHmr: true,
    };
    const bundleType = ctx.config.workspace === Workspace.Internal || ctx.config.workspace === Workspace.Mrt
        ? 'internal'
        : 'platform';
    const bundle = {
        type: bundleType,
        name: name,
        namespace: namespace ?? 'c',
        files,
        options,
    };
    const compilerConfigs = [
        {
            outputConfig: { minify: false, sourcemap: !!outputConfig?.sourcemap },
            experimentalDynamicComponent: experimentalDynamicComponent,
        },
    ];
    return {
        bundle,
        compilerConfigs,
    };
}
export async function compile(ctx, { module, part }, compileOptions) {
    const sources = await module.getSources(part);
    const compileConfig = transformOptionsToPlatformCompileConfig(ctx, compileOptions, sources);
    const result = await measureOperationTime('compile-time', () => platformCompile(compileConfig), ctx.config.lifecycle);
    if (!result.success) {
        ctx.logger.error(`Failed to compile ${part}. \n\tDiagnostics: ${JSON.stringify(result.diagnostics)}`);
        return { code: undefined, warnings: result.diagnostics };
    }
    return {
        code: result.results?.[0].code,
        warnings: result.diagnostics,
    };
}
//# sourceMappingURL=lexBundler.js.map