/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: MIT
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/MIT
 */
import { isHmrDataInbound, } from '@lwc/lwc-dev-server-types';
import { UNRECOGNIZED_MESSAGE_TYPE } from '../../labels.js';
/**
 * This class represents a WebSocket connection.
 * It provides methods to marshal and unmarshal data between hmr-client and dev server.
 */
export class Connection {
    constructor(socket, logger) {
        this.socket = socket;
        this.logger = logger;
    }
    close() {
        this.socket.close();
    }
    onClose(callback) {
        this.socket.on('close', callback);
    }
    send(data) {
        this.socket.send(JSON.stringify(data));
    }
    receive(callback) {
        this.socket.addEventListener('message', ({ data }) => {
            if (typeof data === 'string') {
                const parsed = JSON.parse(data);
                if (isHmrDataInbound(parsed)) {
                    callback(parsed);
                }
                else {
                    this.logger.error(`[LWC Dev Server] Blocking unexpected type of data received from hmr-client '${data}'`);
                }
            }
            else {
                this.logger.error(UNRECOGNIZED_MESSAGE_TYPE);
            }
        });
    }
}
//# sourceMappingURL=connection.js.map