import { EventEmitter } from 'events';
import { FSWatcher } from 'chokidar';
import { Logger } from '@salesforce/core';
import { ServerConfig } from '../../types/index.js';
import { Module, ModulePart } from './module.js';
import type { WorkspaceScanner } from './workspaceScanner/scanner';
export interface EventMap {
    update: [string];
    close: [];
    delete: [string];
    'delete-module': [string];
}
export declare class ModuleGraph extends EventEmitter<EventMap> {
    logger: Logger;
    watcher: FSWatcher;
    workspaceScanner: WorkspaceScanner;
    modules: Map<string, Module>;
    constructor(config: ServerConfig, logger: Logger);
    private init;
    /**
     * Gets the stale modules from the list of modules
     * @param modules
     * @returns Modules paths that are determined to be stale wrt the content monitored by the dev server
     */
    getStaleModules(modules: {
        id: string;
        part: string;
        hash: string;
    }[]): Set<string>;
    private fileChangeHandler;
    private fileAddHandler;
    private fileDeleteHandler;
    getModulePart(modulePath: string): ModulePart | undefined;
    private getModulePartByFile;
    close(): void;
}
