export interface ModuleInfo {
    moduleSourceHash: string;
}
export type ModulePart = {
    module: Module;
    part: string;
};
/**
 * Represents a Module entry per LWC component
 */
export declare class Module {
    baseDir: string;
    namespace: string;
    name: string;
    /**
     * Various parts of the module.
     * For example:
     * {
     *      "myComponent.js": { moduleHash: "xxx" },
     *      "myComponent.html": { moduleHash: "xxy" },
     *      "util/util.js": { moduleHash: "xxz" },
     * }
     */
    private moduleParts;
    constructor(baseDir: string, namespace: string, name: string, 
    /**
     * Various parts of the module.
     * For example:
     * {
     *      "myComponent.js": { moduleHash: "xxx" },
     *      "myComponent.html": { moduleHash: "xxy" },
     *      "util/util.js": { moduleHash: "xxz" },
     * }
     */
    moduleParts: {
        [key: string]: ModuleInfo;
    });
    id(part?: string): string;
    /**
     * Returns the entry file of this module. Not cached because it can change overtime.
     * @returns entry file of the module
     */
    getEntryFile(): string;
    getEntryPart(): string;
    /**
     * Identify which modulePath that represents the boundary of the changed module.
     * In the case of .html files, the module boundary is the template file itself. swapTemplate()
     *  is called and module swap is done.
     * In the case of .css files, the module boundary is the css file itself, swapStyle() is called
     *  and module swap is done.
     * In the case of .js files, the module boundary is the main entry file of the module, all the files
     *  reachable from the entry module are bundled and swapComponent invoked.
     *  Since JS hot swap is currently supporting components, this focused update of the main entry file
     *  is acceptable.
     * @param modulePart The module that changed
     * @return The modulePath of the boundary that needs to be updated.
     */
    getModuleBoundary(modulePart: string): string;
    /**
     * Fetch files and source related to the modulePath that is being hot loaded.
     * @param {string} modulePart The formatted path for the file being compiled.
     * @returns
     */
    getSources(modulePart: string): Promise<any>;
    /**
     * Delets the part and returns the entry file of the module
     * @param part part of the module to be deleted
     */
    deletePart(part: string): void;
    getPart(part: string): ModuleInfo;
    /**
     * Updates the part of this module by recomputing its hash
     * @param part part of the module to update
     * @returns true if successful or false if it wasn't needed
     */
    addOrUpdatePart(part: string): boolean;
}
export declare class InvalidModuleError extends Error {
}
