import path from 'node:path';
import { Workspace } from '../../../../types/serverConfig.js';
import InternalWorkspaceScanner from '../internal.js';
describe('Internal Workspace Scanner', () => {
    it('should add all modules to module map when no exclude paths are provided', () => {
        const workspaceScanner = new InternalWorkspaceScanner(Workspace.Internal, [
            path.resolve(__dirname, './data/internal/ui-force-components'),
            path.resolve(__dirname, './data/internal/ui'),
        ], {});
        const dirs = workspaceScanner.findModuleDirs();
        expect(dirs).toEqual([
            path.resolve(__dirname, 'data/internal/ui-force-components/modules/ns/sample'),
            path.resolve(__dirname, 'data/internal/ui-force-components/modules/ns/exclude'),
            path.resolve(__dirname, 'data/internal/ui/components/modules/uins/sample'),
            path.resolve(__dirname, 'data/internal/ui/components/modules/uins/exclude'),
        ]);
        expect(workspaceScanner.getModules().map((m) => m.id())).toEqual([
            'ns/sample',
            'ns/exclude',
            'uins/sample',
            'uins/exclude',
        ]);
    });
    it('should not add excluded modules to module map', () => {
        const workspaceScanner = new InternalWorkspaceScanner(Workspace.Internal, [
            path.resolve(__dirname, './data/internal/ui-force-components'),
            path.resolve(__dirname, './data/internal/ui'),
        ], {}, [
            path.resolve(__dirname, './data/internal/ui-force-components/modules/ns/exclude'),
            path.resolve(__dirname, './data/internal/ui/components/modules/uins/exclude'),
        ]);
        const dirs = workspaceScanner.findModuleDirs();
        expect(dirs).toEqual([
            path.resolve(__dirname, 'data/internal/ui-force-components/modules/ns/sample'),
            path.resolve(__dirname, 'data/internal/ui/components/modules/uins/sample'),
        ]);
        expect(workspaceScanner.getModules().map((m) => m.id())).toEqual([
            'ns/sample',
            'uins/sample',
        ]);
    });
});
//# sourceMappingURL=internal.spec.js.map