import { Logger } from '@salesforce/core';
import { Module } from '../module.js';
import type { Workspace } from '../../../types/index';
/**
 * An interface to define a workspace scanner that will build a map of modules and its assets in a given workspace.
 * It accepts a set of directories and returns a map of Module Ids to file paths.
 */
export interface WorkspaceScanner {
    /**
     * Defines the type of workspace.
     */
    workspace: Workspace;
    /**
     * The LWC modules directories contained in this workspace.
     * In internal workspace type, the values will be the ["core/ui-xx-modules"] folders.
     * In Salesforce CLI workspace type, the value will be ["workspace/ui-module/my-project/force-app/main/default/"] folder.
     */
    modulesPaths: string[];
    /**
     * Gets all modules in modulesPaths
     */
    getModules(): Module[];
    /**
     * The LWC module directories that needs to be excluded from scanning.
     * In internal workspace type, the value will be ["core/ui-xx-components/modules/ns/compName_to_exclude"]
     * TODO: Add support for Salesforce CLI workspace
     */
    excludePaths?: string[];
}
export declare abstract class BaseWorkspaceScanner implements WorkspaceScanner {
    workspace: Workspace;
    modulesPaths: string[];
    logger: Logger;
    excludePaths?: string[];
    constructor(workspace: Workspace, modulesPaths: string[], logger: Logger, excludePaths?: string[]);
    /**
     * Get all modules in the workspace.
     */
    getModules(): Module[];
    abstract getNamespace(moduleDir: string): string;
    abstract findModuleDirs(): string[];
    scanModuleDir(moduleDir: string): Module | undefined;
}
