import path from 'node:path';
import { Module } from '../module.js';
import { getComponentParts } from './fileReader.js';
export class BaseWorkspaceScanner {
    constructor(workspace, modulesPaths, logger, excludePaths) {
        this.workspace = workspace;
        this.modulesPaths = modulesPaths;
        this.excludePaths = excludePaths;
        this.logger = logger;
    }
    /**
     * Get all modules in the workspace.
     */
    getModules() {
        return this.findModuleDirs()
            .flatMap((dir) => this.scanModuleDir(dir))
            .filter((x) => !!x);
    }
    scanModuleDir(moduleDir) {
        const { base } = path.parse(moduleDir);
        const namespace = this.getNamespace(moduleDir);
        const moduleParts = getComponentParts(moduleDir);
        if (!moduleParts) {
            return;
        }
        return new Module(moduleDir, namespace, base, moduleParts);
    }
}
//# sourceMappingURL=scanner.js.map