import * as crypto from 'node:crypto';
const IV_LENGTH = 12; // 96 bit
const GCM_TAG_LENGTH = 16; // 128 bit
/**
 * Decrypt a Base64 encoded string using AES-GCM
 * @param encryptedText - The Base64 encoded encrypted text
 * @param base64Key - The Base64 encoded key
 * @returns The decrypted text
 */
export function decrypt(encryptedText, base64Key) {
    const key = Buffer.from(base64Key, 'base64');
    const encryptedData = Buffer.from(encryptedText, 'base64');
    const iv = encryptedData.subarray(0, IV_LENGTH);
    const ciphertext = encryptedData.subarray(IV_LENGTH, encryptedData.length - GCM_TAG_LENGTH);
    const authTag = encryptedData.subarray(encryptedData.length - GCM_TAG_LENGTH);
    const decipher = crypto.createDecipheriv('aes-256-gcm', key, iv);
    decipher.setAuthTag(authTag);
    let decrypted = decipher.update(ciphertext, undefined, 'base64');
    decrypted += decipher.final('base64');
    return decrypted;
}
//# sourceMappingURL=aes.js.map