import { describe, it, expect, vi, beforeEach, afterEach } from 'vitest';
import { watch } from 'chokidar';
import { startWatch, stopWatch } from './index.js'; // Adjust the path accordingly
vi.mock('chokidar', () => ({
    watch: vi.fn().mockReturnValue({
        close: vi.fn(),
    }),
}));
describe('File Watcher Module', () => {
    let mockWatcher;
    beforeEach(() => {
        //@ts-expect-error mocked
        mockWatcher = watch();
    });
    afterEach(() => {
        vi.clearAllMocks();
    });
    it('should start watching directories with correct glob patterns', () => {
        const dirPaths = ['/path/to/dir1', '/path/to/dir2/'];
        const result = startWatch(dirPaths);
        expect(watch).toHaveBeenCalledWith(['/path/to/dir1/**/*.{html,css,js,ts}', '/path/to/dir2/**/*.{html,css,js,ts}'], { ignoreInitial: true });
        expect(result).toBe(mockWatcher);
    });
    it('should stop watching when stopWatch is called', () => {
        startWatch(['/path/to/dir']);
        stopWatch();
        expect(mockWatcher.close).toHaveBeenCalled();
    });
    it('should not throw if stopWatch is called before startWatch', () => {
        expect(() => stopWatch()).not.toThrow();
    });
});
//# sourceMappingURL=index.spec.js.map