import { templateString } from './utils';
describe('templateString', () => {
    it('should replace placeholders with corresponding arguments', () => {
        const template = 'Hello, {0}!';
        const args = ['world'];
        expect(templateString(template, args)).toBe('Hello, world!');
    });
    it('should replace multiple placeholders with corresponding arguments', () => {
        const template = 'Hello, {0} {1}!';
        const args = ['John', 'Doe'];
        expect(templateString(template, args)).toBe('Hello, John Doe!');
    });
    it('should handle placeholders in any order', () => {
        const template = '{1}, {0}';
        const args = ['first', 'second'];
        expect(templateString(template, args)).toBe('second, first');
    });
    it('should handle placeholders appearing more than once', () => {
        const template = '{0} and {0} again';
        const args = ['repeat'];
        expect(templateString(template, args)).toBe('repeat and repeat again');
    });
    it('should return the original string if no placeholders are present', () => {
        const template = 'Hello, world!';
        const args = [];
        expect(templateString(template, args)).toBe('Hello, world!');
    });
    it('should handle missing arguments by replacing with undefined', () => {
        const template = 'Hello, {0} {1}!';
        const args = ['John'];
        expect(templateString(template, args)).toBe('Hello, John undefined!');
    });
    it('should handle non-numeric placeholders as literals', () => {
        const template = 'This is not a placeholder: {foo}';
        const args = [];
        expect(templateString(template, args)).toBe('This is not a placeholder: {foo}');
    });
    it('should ignore extra arguments that do not have placeholders', () => {
        const template = 'Hello, {0}!';
        const args = ['world', 'extra'];
        expect(templateString(template, args)).toBe('Hello, world!');
    });
    it('should handle a large number of placeholders', () => {
        const template = '{0} {1} {2} {3} {4}';
        const args = ['a', 'b', 'c', 'd', 'e'];
        expect(templateString(template, args)).toBe('a b c d e');
    });
});
//# sourceMappingURL=utils.test.js.map